function [CRB_mat FIM]      =     crb_cp(A,B,C,sigma_n)
%-------------------------------------------------------------------------%
% CRB_mat      =     crb_cp(A,B,C,sigma_n)
%
% Cramr-Rao bound for the CP decomposition under additive Gaussian noise.
%
% The inputs are:
% 
% - A,B         : factors for the first CP model;
% - A_p,B_p     : factors for the second CP model;
% - C           : coupling factor.
%
% The outputs are:
% 
% - CRB         : Cramr-Rao bound.
%
% List of updates                 -     16/03/2015  -     Rodrigo Cabral
%                                       Creation of the file 
%-------------------------------------------------------------------------%

%-------------------------------Parameters--------------------------------%
% Tensor dimensions
dim             =     [size(A,1) size(B,1) size(C,1)];
R               =     size(A,2);
% Matrices relating the vectorizations of the unfoldings
[J_12,J_13,~]   =     vec_unfold(dim);
%-------------------------------------------------------------------------%

%---------------------------------FI and CRB------------------------------%
% Evaluation of the Khatri-Rao products
ckrb=     kr(C,B);
ckra=     kr(C,A);   
bkra=     kr(B,A);
% Matrix to evaluate the Fisher information
M   =     [kron(ckrb.',eye(dim(1)));...
          kron(ckra.',eye(dim(2)))*J_12;...
          kron(bkra.',eye(dim(3)))*J_13];
% Fisher information matrix
FIM =     (M*(M'));
% Deleting rows and columns of known elements
I         =     [1:dim(1):dim(1)*R dim(1)*R+1:dim(2):(dim(1)+dim(2))*R];
FIM(I,:)  =     [];   FIM(:,I)  =     [];
% Evaluating the Cramr-Rao bound
CRB_mat   =     (sigma_n^2)*pinv(FIM);
%-------------------------------------------------------------------------%
end