function  [A_cor,B_cor,C_cor]     =    ...
                             amb_correct_beta(beta,A_hat,B_hat,C_hat,A,B,C)
%-------------------------------------------------------------------------%
% [A_cor,B_cor,C_cor]     =    ...
%                            amb_correct_beta(beta,A_hat,B_hat,C_hat,A,B,C)
% Correction of the permutation ambiguity of the CP model for positive 
% models. Correction is done by minimizing a beta divergence.
%
% The inputs are:
%
% - beta        : Beta divergence parameter (beta>0);
% - A_hat...    : estimated factors without correction;
% - A,...       : true factors.
%
% The outputs are:
% 
% - A_cor,...   : factors with corrected sign and permutations.
%
% List of updates                 -     22/01/2015  -     R. C. Farias
%                                       Creation of the file 
%                                 -     11/02/2016  -     R. C. Farias
%                                       Modification for beta divergence
%-------------------------------------------------------------------------%

%-------------------------Permutation correction--------------------------%
% Number of components
R   =     size(A,2);

% Repeated parameters for evaluation of the true error
p         =     perms(1:R)';
X_rep     =     [A;B;C];
X_rep     =     X_rep(:);
X_rep     =     repmat(X_rep,1,length(p));
% Possible permutations
X_hat     =     [A_hat;B_hat;C_hat];
X_hat_perm      =     X_hat(:,p(:)');
X_hat_perm      =     reshape(X_hat_perm,[size(X_hat,1)*R,length(p)]);

% Evaluation of the beta divergences and optimal permutations
beta_div        =     zeros(1,length(p));
for       i     =     1:length(p)
     beta_div(i)=     beta_div_eval(X_hat_perm(:,i),X_rep(:,i),beta);
end
[~,I_hat]       =     min(beta_div);

% Permutation of the columns
A_cor     =     A_hat(:,p(:,I_hat)');
B_cor     =     B_hat(:,p(:,I_hat)');
C_cor     =     C_hat(:,p(:,I_hat)');
%-------------------------------------------------------------------------%
end