function [beta_div]   =     beta_div_eval(Y,X,beta)
%-------------------------------------------------------------------------%
% beta_div     =     beta_div_eval(Y,X,beta)
%
% This function evaluates the beta divergence between data Y and model X.
%
% The inputs are:
% 
% - Y           : data block;
% - X           : model;
% - beta        : beta divergence index.
%
% The outputs are:
% 
% - beta_div    : value of the beta divergence.
%
% List of updates                 -     02/04/2015  -     Rodrigo Cabral
%                                       Creation of the file 
%-------------------------------------------------------------------------%

%-------------------------------Evalutaion--------------------------------%
% Case beta=1
if  beta  ==    1
    YlogY       =     Y.*log(Y);
    YlogY(Y==0) =     0;
    d_beta      =     YlogY-Y.*log(X)+X-Y;
    beta_div    =     sum(d_beta(:));
elseif    beta  ==    2
    d_beta      =     -log(Y./X)+(Y./X)-1;
    beta_div    =     sum(d_beta(:));
else
    d_beta      =     (1/((1-beta)*(2-beta)))*((Y.^(2-beta))-...
                      (2-beta).*Y.*(X.^(1-beta))+(1-beta)*(X.^(2-beta)));
    beta_div    =     sum(d_beta(:));
end
%-------------------------------------------------------------------------%
end