function  [Y]   =     gen_tweedie(X,beta,phi)
%-------------------------------------------------------------------------%
% [Y]   =     gen_tweedie(X,beta,delta)
%
% Generation of independent Tweedie samples with means given by X.
%
% The inputs are:
% 
% - X     : array with the means of the random variables;
% - beta  : power of the variance function (allowed values=0,1,2,3).
%           It can also be interpreted as a shape parameter;
% - phi   : dispersion parameter.                
%
% The outputs are:
% 
% - Y     : noise samples.
%
% List of updates                 -     03/01/2015   -     Rodrigo Cabral
%                                       Creation of the file 
%-------------------------------------------------------------------------%

%--------------------Gaussian distribution (beta=0)-----------------------%
if  beta  ==    0
    Y     =     X+sqrt(phi)*randn(size(X));
end
%-------------------------------------------------------------------------%

%--------------------Poisson distribution (beta=1)------------------------%
if  beta  ==    1
    Y     =     poissrnd(X);
end
%-------------------------------------------------------------------------%

%----------------------Gamma distribution (beta=2)------------------------%
if  beta  ==    2
    Y     =     gamrnd(1/phi,phi*X);
end
%-------------------------------------------------------------------------%

%----------------Inverse Gaussian distribution (beta=3)-------------------%
if  beta  ==    3
    V     =     randn(size(X)).^2;
    Y     =     X+((phi/2)*(X.^2).*V)-(phi/2)*X.*sqrt((4/phi)*X.*V...
                +((X.^2).*(V.^2)));
    Z     =     rand(size(X));
    W     =     (X.^2)./Y;
    Ind   =     find(Z>(X./(X+Y)));
    Y(Ind)=     W(Ind);
end
%-------------------------------------------------------------------------%
end